@@ -2409,7 +2409,7 @@ emit_async_open_response (gpointer data)
 	EBookOp *op = data;
 	EBook *book = op->book;
 
-	printf ("in async_open_response\n");
+	d(printf ("in async_open_response\n"));
 
 	g_mutex_lock (book->priv->mutex);
 
@@ -2443,7 +2443,7 @@ e_book_response_open (EBook       *book,
 {
 	EBookOp *op;
 
-	printf ("in e_book_response_open\n");
+	d(printf ("in e_book_response_open\n"));
 
 	g_mutex_lock (book->priv->mutex);
 
@@ -2871,8 +2871,9 @@ fetch_corba_book (EBook       *book,
 			     _("e_book_load_uri: Could not create EBookListener"));
 		return FALSE;
 	}
-	book->priv->listener_signal = g_signal_connect (book->priv->listener, "response",
-							G_CALLBACK (e_book_handle_response), book);
+	book->priv->listener_signal = g_signal_connect_object (book->priv->listener, "response",
+							       G_CALLBACK (e_book_handle_response),
+							       book, 0);
 
 	g_free (book->priv->uri);
 	book->priv->uri = uri;
@@ -3059,6 +3060,7 @@ e_book_get_self (EContact **contact, EBook **book, GError **error)
 {
 	GError *e = NULL;
 	GConfClient *gconf;
+	gboolean status;
 	char *uid;
 
 	*book = e_book_new_system_addressbook (&e);
@@ -3069,6 +3071,13 @@ e_book_get_self (EContact **contact, EBook **book, GError **error)
 		return FALSE;
 	}
 
+	status = e_book_open (*book, FALSE, &e);
+	if (status == FALSE) {
+		if (error)
+			g_propagate_error (error, e);
+		return FALSE;
+	}
+
 	gconf = gconf_client_get_default();
 	uid = gconf_client_get_string (gconf, SELF_UID_KEY, NULL);
 	g_object_unref (gconf);
@@ -3511,7 +3520,9 @@ e_book_dispose (GObject *object)
 		CORBA_exception_free (&ev);
 
 		if (book->priv->listener) {
-			g_signal_handler_disconnect (book->priv->listener, book->priv->listener_signal);
+			/* GLib bug compatibility */
+			if (g_signal_handler_is_connected (book->priv->listener, book->priv->listener_signal))
+				g_signal_handler_disconnect (book->priv->listener, book->priv->listener_signal);
 			bonobo_object_unref (book->priv->listener);
 			book->priv->listener = NULL;
 		}
